@@ -208,23 +208,23 @@ author:
 '''
 
 EXAMPLES = '''
-    - name: Create a VirtualHub
-      azure_rm_virtualhub:
-        resource_group: myResourceGroup
-        name: my_virtual_hub_name
-        address_prefix: 10.2.0.0/24
-        sku: Standard
-        location: eastus
-        enable_virtual_router_route_propogation: false
-        virtual_wan:
-          id: /subscriptions/xxx-xxx/resourceGroups/myResourceGroup/providers/Microsoft.Network/virtualWans/fredwan
+- name: Create a VirtualHub
+  azure_rm_virtualhub:
+    resource_group: myResourceGroup
+    name: my_virtual_hub_name
+    address_prefix: 10.2.0.0/24
+    sku: Standard
+    location: eastus
+    enable_virtual_router_route_propogation: false
+    virtual_wan:
+      id: /subscriptions/xxx-xxx/resourceGroups/myResourceGroup/providers/Microsoft.Network/virtualWans/fredwan
 
-    - name: Delete VirtualHub
-      azure_rm_virtualhub:
-        resource_group: myResourceGroup
-        name: my_virtual_hub_name
-        location: eastus
-        state: absent
+- name: Delete VirtualHub
+  azure_rm_virtualhub:
+    resource_group: myResourceGroup
+    name: my_virtual_hub_name
+    location: eastus
+    state: absent
 '''
 
 RETURN = '''
@@ -493,9 +493,8 @@ state:
 
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBaseExt
 try:
-    from msrestazure.azure_exceptions import CloudError
-    from msrestazure.azure_operation import AzureOperationPoller
-    from msrest.polling import LROPoller
+    from azure.core.exceptions import ResourceNotFoundError
+    from azure.core.polling import LROPoller
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -730,21 +729,21 @@ class AzureRMVirtualHub(AzureRMModuleBaseExt):
 
     def create_update_resource(self):
         try:
-            response = self.network_client.virtual_hubs.create_or_update(resource_group_name=self.resource_group,
-                                                                         virtual_hub_name=self.name,
-                                                                         virtual_hub_parameters=self.body)
-            if isinstance(response, AzureOperationPoller) or isinstance(response, LROPoller):
+            response = self.network_client.virtual_hubs.begin_create_or_update(resource_group_name=self.resource_group,
+                                                                               virtual_hub_name=self.name,
+                                                                               virtual_hub_parameters=self.body)
+            if isinstance(response, LROPoller):
                 response = self.get_poller_result(response)
-        except CloudError as exc:
+        except Exception as exc:
             self.log('Error attempting to create the VirtualHub instance.')
             self.fail('Error creating the VirtualHub instance: {0}'.format(str(exc)))
         return response.as_dict()
 
     def delete_resource(self):
         try:
-            response = self.network_client.virtual_hubs.delete(resource_group_name=self.resource_group,
-                                                               virtual_hub_name=self.name)
-        except CloudError as e:
+            response = self.network_client.virtual_hubs.begin_delete(resource_group_name=self.resource_group,
+                                                                     virtual_hub_name=self.name)
+        except Exception as e:
             self.log('Error attempting to delete the VirtualHub instance.')
             self.fail('Error deleting the VirtualHub instance: {0}'.format(str(e)))
 
@@ -754,7 +753,7 @@ class AzureRMVirtualHub(AzureRMModuleBaseExt):
         try:
             response = self.network_client.virtual_hubs.get(resource_group_name=self.resource_group,
                                                             virtual_hub_name=self.name)
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             return False
         return response.as_dict()
 
