@@ -1,12 +1,14 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2021, Cisco Systems
+# Copyright (c) 2024, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import (absolute_import, division, print_function)
+from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 from ansible.plugins.action import ActionBase
+
 try:
     from ansible_collections.ansible.utils.plugins.module_utils.common.argspec_validate import (
         AnsibleArgSpecValidator,
@@ -24,15 +26,17 @@ from ansible_collections.cisco.ise.plugins.plugin_utils.ise import (
 # Get common arguements specification
 argument_spec = ise_argument_spec()
 # Add arguments specific for this module
-argument_spec.update(dict(
-    id=dict(type="str"),
-    page=dict(type="int"),
-    size=dict(type="int"),
-    sortasc=dict(type="str"),
-    sortdsc=dict(type="str"),
-    filter=dict(type="list"),
-    filterType=dict(type="str"),
-))
+argument_spec.update(
+    dict(
+        id=dict(type="str"),
+        page=dict(type="int"),
+        size=dict(type="int"),
+        sortasc=dict(type="str"),
+        sortdsc=dict(type="str"),
+        filter=dict(type="list"),
+        filterType=dict(type="str"),
+    )
+)
 
 required_if = []
 required_one_of = []
@@ -43,7 +47,9 @@ required_together = []
 class ActionModule(ActionBase):
     def __init__(self, *args, **kwargs):
         if not ANSIBLE_UTILS_IS_INSTALLED:
-            raise AnsibleActionFail("ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'")
+            raise AnsibleActionFail(
+                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
+            )
         super(ActionModule, self).__init__(*args, **kwargs)
         self._supports_async = False
         self._supports_check_mode = True
@@ -85,7 +91,7 @@ class ActionModule(ActionBase):
         self._result["changed"] = False
         self._check_argspec()
 
-        self._result.update(dict(ise_response={}))
+        self._result.update(dict(ise_response=[]))
 
         ise = ISESDK(params=self._task.args)
 
@@ -94,9 +100,9 @@ class ActionModule(ActionBase):
         if id:
             response = ise.exec(
                 family="ip_to_sgt_mapping",
-                function='get_ip_to_sgt_mapping_by_id',
-                params=self.get_object(self._task.args)
-            ).response['SGMapping']
+                function="get_ip_to_sgt_mapping_by_id",
+                params=self.get_object(self._task.args),
+            ).response["SGMapping"]
             self._result.update(dict(ise_response=response))
             self._result.update(ise.exit_json())
             return self._result
@@ -104,17 +110,16 @@ class ActionModule(ActionBase):
             responses = []
             generator = ise.exec(
                 family="ip_to_sgt_mapping",
-                function='get_ip_to_sgt_mapping_generator',
+                function="get_ip_to_sgt_mapping_generator",
                 params=self.get_object(self._task.args),
             )
             try:
                 for item in generator:
-                    tmp_response = item.response['SearchResult']['resources']
+                    tmp_response = item.response["SearchResult"]["resources"]
                     if isinstance(tmp_response, list):
                         responses += tmp_response
                     else:
                         responses.append(tmp_response)
-                self._result.update(dict(ise_responses=responses))
                 response = responses
             except (TypeError, AttributeError) as e:
                 ise.fail_json(
