@@ -1,42 +1,47 @@
+# -*- coding: utf-8 -*-
 # Copyright (C) 2016 maxn nikolaev.makc@gmail.com
 # Copyright (c) 2017 Ansible Project
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
-DOCUMENTATION = '''
-    author: Unknown (!UNKNOWN)
-    callback: jabber
-    type: notification
-    short_description: post task events to a jabber server
-    description:
-      - The chatty part of ChatOps with a Hipchat server as a target
-      - This callback plugin sends status updates to a HipChat channel during playbook execution.
-    requirements:
-      - xmpp (python lib https://github.com/ArchipelProject/xmpppy)
-    options:
-      server:
-        description: connection info to jabber server
-        required: True
-        env:
-          - name: JABBER_SERV
-      user:
-        description: Jabber user to authenticate as
-        required: True
-        env:
-          - name: JABBER_USER
-      password:
-        description: Password for the user to the jabber server
-        required: True
-        env:
-          - name: JABBER_PASS
-      to:
-        description: chat identifier that will receive the message
-        required: True
-        env:
-          - name: JABBER_TO
-'''
+DOCUMENTATION = r"""
+author: Unknown (!UNKNOWN)
+name: jabber
+type: notification
+short_description: post task events to a Jabber server
+description:
+  - The chatty part of ChatOps with a Hipchat server as a target.
+  - This callback plugin sends status updates to a HipChat channel during playbook execution.
+requirements:
+  - xmpp (Python library U(https://github.com/ArchipelProject/xmpppy))
+options:
+  server:
+    description: Connection info to Jabber server.
+    type: str
+    required: true
+    env:
+      - name: JABBER_SERV
+  user:
+    description: Jabber user to authenticate as.
+    type: str
+    required: true
+    env:
+      - name: JABBER_USER
+  password:
+    description: Password for the user to the Jabber server.
+    type: str
+    required: true
+    env:
+      - name: JABBER_PASS
+  to:
+    description: Chat identifier that will receive the message.
+    type: str
+    required: true
+    env:
+      - name: JABBER_TO
+"""
 
 import os
 
@@ -96,7 +101,7 @@ class CallbackModule(CallbackBase):
         """Display Playbook and play start messages"""
         self.play = play
         name = play.name
-        self.send_msg("Ansible starting play: %s" % (name))
+        self.send_msg(f"Ansible starting play: {name}")
 
     def playbook_on_stats(self, stats):
         name = self.play
@@ -112,7 +117,7 @@ class CallbackModule(CallbackBase):
 
         if failures or unreachable:
             out = self.debug
-            self.send_msg("%s: Failures detected \n%s \nHost: %s\n Failed at:\n%s" % (name, self.task, h, out))
+            self.send_msg(f"{name}: Failures detected \n{self.task} \nHost: {h}\n Failed at:\n{out}")
         else:
             out = self.debug
-            self.send_msg("Great! \n Playbook %s completed:\n%s \n Last task debug:\n %s" % (name, s, out))
+            self.send_msg(f"Great! \n Playbook {name} completed:\n{s} \n Last task debug:\n {out}")
