@@ -19,8 +19,8 @@ mandatory_py_version = pytest.mark.skipif(
 )
 
 from ansible_collections.community.general.plugins.modules import proxmox_vm_info
-from ansible_collections.community.general.tests.unit.compat.mock import patch
-from ansible_collections.community.general.tests.unit.plugins.modules.utils import (
+from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import patch
+from ansible_collections.community.internal_test_tools.tests.unit.plugins.modules.utils import (
     AnsibleExitJson,
     AnsibleFailJson,
     ModuleTestCase,
@@ -414,7 +414,7 @@ EXPECTED_VMS_OUTPUT = [
 ]
 
 
-def get_module_args(type="all", node=None, vmid=None, name=None):
+def get_module_args(type="all", node=None, vmid=None, name=None, config="none"):
     return {
         "api_host": "host",
         "api_user": "user",
@@ -423,6 +423,7 @@ def get_module_args(type="all", node=None, vmid=None, name=None):
         "type": type,
         "vmid": vmid,
         "name": name,
+        "config": config,
     }
 
 
@@ -451,45 +452,43 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
 
     def test_module_fail_when_required_args_missing(self):
         with pytest.raises(AnsibleFailJson) as exc_info:
-            set_module_args({})
-            self.module.main()
+            with set_module_args({}):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["msg"] == "missing required arguments: api_host, api_user"
 
     def test_get_lxc_vms_information(self):
         with pytest.raises(AnsibleExitJson) as exc_info:
-            set_module_args(get_module_args(type="lxc"))
-            self.module.main()
+            with set_module_args(get_module_args(type="lxc")):
+                expected_output = [vm for vm in EXPECTED_VMS_OUTPUT if vm["type"] == "lxc"]
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["changed"] is False
-        assert result["proxmox_vms"] == [
-            vm for vm in EXPECTED_VMS_OUTPUT if vm["type"] == "lxc"
-        ]
+        assert result["proxmox_vms"] == expected_output
 
     def test_get_qemu_vms_information(self):
         with pytest.raises(AnsibleExitJson) as exc_info:
-            set_module_args(get_module_args(type="qemu"))
-            self.module.main()
+            with set_module_args(get_module_args(type="qemu")):
+                expected_output = [vm for vm in EXPECTED_VMS_OUTPUT if vm["type"] == "qemu"]
+                self.module.main()
 
         result = exc_info.value.args[0]
-        assert result["proxmox_vms"] == [
-            vm for vm in EXPECTED_VMS_OUTPUT if vm["type"] == "qemu"
-        ]
+        assert result["proxmox_vms"] == expected_output
 
     def test_get_all_vms_information(self):
         with pytest.raises(AnsibleExitJson) as exc_info:
-            set_module_args(get_module_args())
-            self.module.main()
+            with set_module_args(get_module_args()):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["proxmox_vms"] == EXPECTED_VMS_OUTPUT
 
     def test_vmid_is_converted_to_int(self):
         with pytest.raises(AnsibleExitJson) as exc_info:
-            set_module_args(get_module_args(type="lxc"))
-            self.module.main()
+            with set_module_args(get_module_args(type="lxc")):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert isinstance(result["proxmox_vms"][0]["vmid"], int)
@@ -502,8 +501,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
                 for vm in EXPECTED_VMS_OUTPUT
                 if vm["vmid"] == vmid and vm["type"] == "lxc"
             ]
-            set_module_args(get_module_args(type="lxc", vmid=vmid))
-            self.module.main()
+            with set_module_args(get_module_args(type="lxc", vmid=vmid)):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["proxmox_vms"] == expected_output
@@ -517,8 +516,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
                 for vm in EXPECTED_VMS_OUTPUT
                 if vm["vmid"] == vmid and vm["type"] == "qemu"
             ]
-            set_module_args(get_module_args(type="qemu", vmid=vmid))
-            self.module.main()
+            with set_module_args(get_module_args(type="qemu", vmid=vmid)):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["proxmox_vms"] == expected_output
@@ -528,8 +527,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
         with pytest.raises(AnsibleExitJson) as exc_info:
             vmid = 100
             expected_output = [vm for vm in EXPECTED_VMS_OUTPUT if vm["vmid"] == vmid]
-            set_module_args(get_module_args(type="all", vmid=vmid))
-            self.module.main()
+            with set_module_args(get_module_args(type="all", vmid=vmid)):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["proxmox_vms"] == expected_output
@@ -543,8 +542,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
 
         with pytest.raises(AnsibleExitJson) as exc_info:
             expected_output = [vm for vm in EXPECTED_VMS_OUTPUT if vm["name"] == name]
-            set_module_args(get_module_args(type="all", name=name))
-            self.module.main()
+            with set_module_args(get_module_args(type="all", name=name)):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["proxmox_vms"] == expected_output
@@ -559,14 +558,14 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
 
         with pytest.raises(AnsibleExitJson) as exc_info:
             expected_output = [vm for vm in EXPECTED_VMS_OUTPUT if vm["name"] == name]
-            set_module_args(get_module_args(type="all", name=name))
-            self.module.main()
+            with set_module_args(get_module_args(type="all", name=name)):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["proxmox_vms"] == expected_output
         assert len(result["proxmox_vms"]) == 2
 
-    def test_get_multiple_vms_with_the_same_name(self):
+    def test_get_vm_with_an_empty_name(self):
         name = ""
         self.connect_mock.return_value.cluster.resources.get.return_value = [
             {"name": name, "vmid": "105"},
@@ -574,8 +573,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
 
         with pytest.raises(AnsibleExitJson) as exc_info:
             expected_output = [vm for vm in EXPECTED_VMS_OUTPUT if vm["name"] == name]
-            set_module_args(get_module_args(type="all", name=name))
-            self.module.main()
+            with set_module_args(get_module_args(type="all", name=name)):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["proxmox_vms"] == expected_output
@@ -588,8 +587,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
                 for vm in EXPECTED_VMS_OUTPUT
                 if vm["node"] == NODE1 and vm["type"] == "lxc"
             ]
-            set_module_args(get_module_args(type="lxc", node=NODE1))
-            self.module.main()
+            with set_module_args(get_module_args(type="lxc", node=NODE1)):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["proxmox_vms"] == expected_output
@@ -602,8 +601,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
                 for vm in EXPECTED_VMS_OUTPUT
                 if vm["node"] == NODE1 and vm["type"] == "qemu"
             ]
-            set_module_args(get_module_args(type="qemu", node=NODE1))
-            self.module.main()
+            with set_module_args(get_module_args(type="qemu", node=NODE1)):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["proxmox_vms"] == expected_output
@@ -612,8 +611,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
     def test_get_all_vms_from_specific_node(self):
         with pytest.raises(AnsibleExitJson) as exc_info:
             expected_output = [vm for vm in EXPECTED_VMS_OUTPUT if vm["node"] == NODE1]
-            set_module_args(get_module_args(node=NODE1))
-            self.module.main()
+            with set_module_args(get_module_args(node=NODE1)):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["proxmox_vms"] == expected_output
@@ -622,8 +621,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
     def test_module_returns_empty_list_when_vm_does_not_exist(self):
         with pytest.raises(AnsibleExitJson) as exc_info:
             vmid = 200
-            set_module_args(get_module_args(type="all", vmid=vmid))
-            self.module.main()
+            with set_module_args(get_module_args(type="all", vmid=vmid)):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert result["proxmox_vms"] == []
@@ -633,8 +632,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
             "Some mocked connection error."
         )
         with pytest.raises(AnsibleFailJson) as exc_info:
-            set_module_args(get_module_args(type="qemu"))
-            self.module.main()
+            with set_module_args(get_module_args(type="qemu")):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert "Failed to retrieve QEMU VMs information:" in result["msg"]
@@ -644,8 +643,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
             "Some mocked connection error."
         )
         with pytest.raises(AnsibleFailJson) as exc_info:
-            set_module_args(get_module_args(type="lxc"))
-            self.module.main()
+            with set_module_args(get_module_args(type="lxc")):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert "Failed to retrieve LXC VMs information:" in result["msg"]
@@ -655,8 +654,8 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
             "Some mocked connection error."
         )
         with pytest.raises(AnsibleFailJson) as exc_info:
-            set_module_args(get_module_args())
-            self.module.main()
+            with set_module_args(get_module_args()):
+                self.module.main()
 
         result = exc_info.value.args[0]
         assert (
@@ -665,13 +664,12 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
         )
 
     def test_module_fail_when_node_does_not_exist(self):
-        self.connect_mock.return_value.nodes.get.return_value = []
         with pytest.raises(AnsibleFailJson) as exc_info:
-            set_module_args(get_module_args(type="all", node=NODE1))
-            self.module.main()
+            with set_module_args(get_module_args(type="all", node="NODE3")):
+                self.module.main()
 
         result = exc_info.value.args[0]
-        assert result["msg"] == "Node pve doesn't exist in PVE cluster"
+        assert result["msg"] == "Node NODE3 doesn't exist in PVE cluster"
 
     def test_call_to_get_vmid_is_not_used_when_vmid_provided(self):
         with patch(
@@ -679,9 +677,38 @@ class TestProxmoxVmInfoModule(ModuleTestCase):
         ) as get_vmid_mock:
             with pytest.raises(AnsibleExitJson):
                 vmid = 100
-                set_module_args(
+                with set_module_args(
                     get_module_args(type="all", vmid=vmid, name="something")
-                )
-                self.module.main()
+                ):
+                    self.module.main()
 
         assert get_vmid_mock.call_count == 0
+
+    def test_config_returned_when_specified_qemu_vm_with_config(self):
+        config_vm_value = {
+            'scsi0': 'local-lvm:vm-101-disk-0,iothread=1,size=32G',
+            'net0': 'virtio=4E:79:9F:A8:EE:E4,bridge=vmbr0,firewall=1',
+            'scsihw': 'virtio-scsi-single',
+            'cores': 1,
+            'name': 'test1',
+            'ostype': 'l26',
+            'boot': 'order=scsi0;ide2;net0',
+            'memory': 2048,
+            'sockets': 1,
+        }
+        (self.connect_mock.return_value.nodes.return_value.qemu.return_value.
+         config.return_value.get.return_value) = config_vm_value
+
+        with pytest.raises(AnsibleExitJson) as exc_info:
+            vmid = 101
+            with set_module_args(get_module_args(
+                type="qemu",
+                vmid=vmid,
+                config="current",
+            )):
+                expected_output = [vm for vm in EXPECTED_VMS_OUTPUT if vm["vmid"] == vmid]
+                expected_output[0]["config"] = config_vm_value
+                self.module.main()
+
+        result = exc_info.value.args[0]
+        assert result["proxmox_vms"] == expected_output
