@@ -2,10 +2,11 @@
 # -*- coding: utf-8 -*-
 
 # Copyright: (c) 2017, Felix Archambault
-# Copyright: (c) 2019, Andrew Klychkov (@Andersson007) <aaklychkov@mail.ru>
+# Copyright: (c) 2019, Andrew Klychkov (@Andersson007) <andrew.a.klychkov@gmail.com>
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-from __future__ import (absolute_import, division, print_function)
+from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 DOCUMENTATION = r'''
@@ -14,15 +15,12 @@ module: postgresql_query
 short_description: Run PostgreSQL queries
 description:
 - Runs arbitrary PostgreSQL queries.
-- Can run queries from SQL script files.
-- Does not run against backup files. Use M(community.postgresql.postgresql_db) with I(state=restore)
-  to run queries on files made by pg_dump/pg_dumpall utilities.
 options:
   query:
     description:
-    - SQL query to run. Variables can be escaped with psycopg2 syntax
-      U(http://initd.org/psycopg/docs/usage.html).
-    type: str
+    - SQL query string or list of queries to run. Variables can be escaped with psycopg syntax
+      U(https://www.psycopg.org/psycopg3/docs/basic/params.html).
+    type: raw
   positional_args:
     description:
     - List of values to be passed as positional arguments to the query.
@@ -36,16 +34,6 @@ options:
       When the value is a list, it will be converted to PostgreSQL array.
     - Mutually exclusive with I(positional_args).
     type: dict
-  path_to_script:
-    description:
-    - Path to a SQL script on the target machine.
-    - If the script contains several queries, they must be semicolon-separated.
-    - To run scripts containing objects with semicolons
-      (for example, function and procedure definitions), use I(as_single_query=yes).
-    - To upload dumps or to execute other complex scripts, the preferable way
-      is to use the M(community.postgresql.postgresql_db) module with I(state=restore).
-    - Mutually exclusive with I(query).
-    type: path
   session_role:
     description:
     - Switch to session_role after connecting. The specified session_role must
@@ -53,19 +41,20 @@ options:
     - Permissions checking for SQL commands is carried out as though
       the session_role were the one that had logged in originally.
     type: str
-  db:
+  login_db:
     description:
     - Name of database to connect to and run queries against.
+    - The V(db) alias is deprecated and will be removed in version 5.0.0.
     type: str
     aliases:
-    - login_db
+    - db
   autocommit:
     description:
     - Execute in autocommit mode when the query can't be run inside a transaction block
       (e.g., VACUUM).
     - Mutually exclusive with I(check_mode).
     type: bool
-    default: no
+    default: false
   encoding:
     description:
     - Set the client encoding for the current session (e.g. C(UTF-8)).
@@ -74,10 +63,10 @@ options:
     version_added: '0.2.0'
   trust_input:
     description:
-    - If C(no), check whether a value of I(session_role) is potentially dangerous.
-    - It makes sense to use C(no) only when SQL injections via I(session_role) are possible.
+    - If C(false), check whether a value of I(session_role) is potentially dangerous.
+    - It makes sense to use C(false) only when SQL injections via I(session_role) are possible.
     type: bool
-    default: yes
+    default: true
     version_added: '0.2.0'
   search_path:
     description:
@@ -85,44 +74,43 @@ options:
     type: list
     elements: str
     version_added: '1.0.0'
-  as_single_query:
-    description:
-    - If C(yes), when reading from the I(path_to_script) file,
-      executes its whole content in a single query.
-    - When C(yes), the C(query_all_results) return value
-      contains only the result of the last statement.
-    - Whether the state is reported as changed or not
-      is determined by the last statement of the file.
-    - Used only when I(path_to_script) is specified, otherwise ignored.
-    - If set to C(no), the script can contain only semicolon-separated queries.
-      (see the I(path_to_script) option documentation).
-    - The default value is C(no).
-    type: bool
-    version_added: '1.1.0'
 seealso:
+- module: community.postgresql.postgresql_script
 - module: community.postgresql.postgresql_db
 - name: PostgreSQL Schema reference
   description: Complete reference of the PostgreSQL schema documentation.
   link: https://www.postgresql.org/docs/current/ddl-schemas.html
+
+attributes:
+  check_mode:
+    support: full
+
 author:
 - Felix Archambault (@archf)
 - Andrew Klychkov (@Andersson007)
 - Will Rouesnel (@wrouesnel)
+
 extends_documentation_fragment:
 - community.postgresql.postgres
-notes:
-- Supports C(check_mode).
 '''
 
 EXAMPLES = r'''
 - name: Simple select query to acme db
   community.postgresql.postgresql_query:
-    db: acme
+    login_db: acme
     query: SELECT version()
 
+# The result of each query will be stored in query_all_results return value
+- name: Run several queries against acme db
+  community.postgresql.postgresql_query:
+    login_db: acme
+    query:
+    - SELECT version()
+    - SELECT id FROM accounts
+
 - name: Select query to db acme with positional arguments and non-default credentials
   community.postgresql.postgresql_query:
-    db: acme
+    login_db: acme
     login_user: django
     login_password: mysecretpass
     query: SELECT * FROM acme WHERE id = %s AND story = %s
@@ -132,7 +120,7 @@ EXAMPLES = r'''
 
 - name: Select query to test_db with named_args
   community.postgresql.postgresql_query:
-    db: test_db
+    login_db: test_db
     query: SELECT * FROM test WHERE id = %(id_val)s AND story = %(story_val)s
     named_args:
       id_val: 1
@@ -140,24 +128,25 @@ EXAMPLES = r'''
 
 - name: Insert query to test_table in db test_db
   community.postgresql.postgresql_query:
-    db: test_db
+    login_db: test_db
     query: INSERT INTO test_table (id, story) VALUES (2, 'my_long_story')
 
-# If your script contains semicolons as parts of separate objects
-# like functions, procedures, and so on, use "as_single_query: yes"
-- name: Run queries from SQL script using UTF-8 client encoding for session
+- name: Use connect_params to add any additional connection parameters that libpg supports
   community.postgresql.postgresql_query:
-    db: test_db
-    path_to_script: /var/lib/pgsql/test.sql
-    positional_args:
-    - 1
-    encoding: UTF-8
+    connect_params:
+      target_session_attrs: read-write
+      connect_timeout: 10
+    login_host: "host1,host2"
+    login_user: "test"
+    login_password: "test1234"
+    login_db: "test"
+    query: 'insert into test (test) values (now())'
 
 - name: Example of using autocommit parameter
   community.postgresql.postgresql_query:
-    db: test_db
+    login_db: test_db
     query: VACUUM
-    autocommit: yes
+    autocommit: true
 
 - name: >
     Insert data to the column of array type using positional_args.
@@ -221,37 +210,35 @@ query:
     description:
     - Executed query.
     - When reading several queries from a file, it contains only the last one.
-    returned: always
+    returned: success
     type: str
     sample: 'SELECT * FROM bar'
 statusmessage:
     description:
     - Attribute containing the message returned by the command.
     - When reading several queries from a file, it contains a message of the last one.
-    returned: always
+    returned: success
     type: str
     sample: 'INSERT 0 1'
 query_result:
     description:
     - List of dictionaries in column:value form representing returned rows.
     - When running queries from a file, returns result of the last query.
-    returned: always
+    returned: success
     type: list
     elements: dict
     sample: [{"Column": "Value1"},{"Column": "Value2"}]
 query_list:
     description:
     - List of executed queries.
-      Useful when reading several queries from a file.
-    returned: always
+    returned: success
     type: list
     elements: str
     sample: ['SELECT * FROM foo', 'SELECT * FROM bar']
 query_all_results:
     description:
     - List containing results of all queries executed (one sublist for every query).
-      Useful when reading several queries from a file.
-    returned: always
+    returned: success
     type: list
     elements: list
     sample: [[{"Column": "Value1"},{"Column": "Value2"}], [{"Column": "Value1"},{"Column": "Value2"}]]
@@ -263,100 +250,90 @@ rowcount:
     returned: changed
     type: int
     sample: 5
+execution_time_ms:
+    description:
+    - A list containing execution time per query in milliseconds.
+    - The measurements are done right before and after passing
+      the query to the driver for execution.
+    returned: success
+    type: list
+    sample: [7104]
+    version_added: '3.10.0'
 '''
 
-try:
-    from psycopg2 import ProgrammingError as Psycopg2ProgrammingError
-    from psycopg2.extras import DictCursor
-except ImportError:
-    # it is needed for checking 'no result to fetch' in main(),
-    # psycopg2 availability will be checked by connect_to_db() into
-    # ansible.module_utils.postgres
-    pass
-
-import datetime
-import decimal
 import re
+import time
 
-from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.postgresql.plugins.module_utils.database import (
-    check_input,
-)
-from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
-    connect_to_db,
-    get_conn_params,
-    postgres_common_argument_spec,
-)
 from ansible.module_utils._text import to_native
+from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.six import iteritems
+from ansible_collections.community.postgresql.plugins.module_utils.database import \
+    check_input
+from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
+    HAS_PSYCOPG,
+    PSYCOPG_VERSION,
+    TYPES_NEED_TO_CONVERT,
+    connect_to_db,
+    convert_elements_to_pg_arrays,
+    convert_to_supported,
+    ensure_required_libs,
+    get_conn_params,
+    pg_cursor_args,
+    postgres_common_argument_spec,
+    set_search_path,
+)
+from ansible_collections.community.postgresql.plugins.module_utils.version import \
+    LooseVersion
+
+if HAS_PSYCOPG and PSYCOPG_VERSION < LooseVersion("3.0"):
+    from psycopg2 import ProgrammingError as PsycopgProgrammingError
+elif HAS_PSYCOPG:
+    from psycopg import ProgrammingError as PsycopgProgrammingError
 
 
 # ===========================================
 # Module execution.
 #
 
-def list_to_pg_array(elem):
-    """Convert the passed list to PostgreSQL array
-    represented as a string.
 
-    Args:
-        elem (list): List that needs to be converted.
+def execute_and_return_time(cursor, query, args):
+    # Measure query execution time in milliseconds as requested in
+    # https://github.com/ansible-collections/community.postgresql/issues/787
+    start_time = time.perf_counter()
 
-    Returns:
-        elem (str): String representation of PostgreSQL array.
-    """
-    elem = str(elem).strip('[]')
-    elem = '{' + elem + '}'
-    return elem
+    cursor.execute(query, args)
+
+    # Calculate the execution time rounding it to 4 decimal places
+    exec_time_ms = round((time.perf_counter() - start_time) * 1000, 4)
+    return cursor, exec_time_ms
 
 
-def convert_elements_to_pg_arrays(obj):
-    """Convert list elements of the passed object
-    to PostgreSQL arrays represented as strings.
+def insane_query(string):
+    for c in string:
+        if c not in (' ', '\n', '', '\t'):
+            return False
 
-    Args:
-        obj (dict or list): Object whose elements need to be converted.
-
-    Returns:
-        obj (dict or list): Object with converted elements.
-    """
-    if isinstance(obj, dict):
-        for (key, elem) in iteritems(obj):
-            if isinstance(elem, list):
-                obj[key] = list_to_pg_array(elem)
-
-    elif isinstance(obj, list):
-        for i, elem in enumerate(obj):
-            if isinstance(elem, list):
-                obj[i] = list_to_pg_array(elem)
-
-    return obj
-
-
-def set_search_path(cursor, search_path):
-    """Set session's search_path.
-
-    Args:
-        cursor (Psycopg2 cursor): Database cursor object.
-        search_path (str): String containing comma-separated schema names.
-    """
-    cursor.execute('SET search_path TO %s' % search_path)
+    return True
 
 
 def main():
     argument_spec = postgres_common_argument_spec()
     argument_spec.update(
-        query=dict(type='str'),
-        db=dict(type='str', aliases=['login_db']),
+        query=dict(type='raw'),
+        login_db=dict(type='str', aliases=['db'], deprecated_aliases=[
+            {
+                'name': 'db',
+                'version': '5.0.0',
+                'collection_name': 'community.postgresql',
+            }],
+        ),
         positional_args=dict(type='list', elements='raw'),
         named_args=dict(type='dict'),
         session_role=dict(type='str'),
-        path_to_script=dict(type='path'),
         autocommit=dict(type='bool', default=False),
         encoding=dict(type='str'),
         trust_input=dict(type='bool', default=True),
         search_path=dict(type='list', elements='str'),
-        as_single_query=dict(type='bool'),
     )
 
     module = AnsibleModule(
@@ -368,20 +345,14 @@ def main():
     query = module.params["query"]
     positional_args = module.params["positional_args"]
     named_args = module.params["named_args"]
-    path_to_script = module.params["path_to_script"]
     autocommit = module.params["autocommit"]
     encoding = module.params["encoding"]
     session_role = module.params["session_role"]
     trust_input = module.params["trust_input"]
     search_path = module.params["search_path"]
-    as_single_query = module.params["as_single_query"]
 
-    if path_to_script and as_single_query is None:
-        module.warn('You use the "path_to_script" option with the "as_single_query" '
-                    'option unset. The default is False and will be changed to True '
-                    'in community.postgresql release 2.0.0. '
-                    'To avoid crashes, please read the documentation '
-                    'and define the "as_single_query" option explicitly.')
+    if query and not isinstance(query, (str, list)):
+        module.fail_json(msg="query argument must be of type string or list")
 
     if not trust_input:
         # Check input for potentially dangerous elements:
@@ -390,33 +361,20 @@ def main():
     if autocommit and module.check_mode:
         module.fail_json(msg="Using autocommit is mutually exclusive with check_mode")
 
-    if path_to_script and query:
-        module.fail_json(msg="path_to_script is mutually exclusive with query")
-
     query_list = []
-    if path_to_script:
-        try:
-            with open(path_to_script, 'rb') as f:
-                query = to_native(f.read())
 
-                if not as_single_query:
-                    if ';' in query:
-                        query_list = [q for q in query.split(';') if q != '\n']
-                    else:
-                        query_list.append(query)
-                else:
-                    query_list.append(query)
-
-        except Exception as e:
-            module.fail_json(msg="Cannot read file '%s' : %s" % (path_to_script, to_native(e)))
-    else:
+    if isinstance(query, str):
         query_list.append(query)
+    else:  # if it's a list
+        query_list = query
 
+    # Ensure psycopg libraries are available before connecting to DB:
+    ensure_required_libs(module)
     conn_params = get_conn_params(module, module.params)
-    db_connection = connect_to_db(module, conn_params, autocommit=autocommit)
     if encoding is not None:
-        db_connection.set_client_encoding(encoding)
-    cursor = db_connection.cursor(cursor_factory=DictCursor)
+        conn_params["client_encoding"] = encoding
+    db_connection, dummy = connect_to_db(module, conn_params, autocommit=autocommit)
+    cursor = db_connection.cursor(**pg_cursor_args)
 
     if search_path:
         set_search_path(cursor, '%s' % ','.join([x.strip(' ') for x in search_path]))
@@ -438,13 +396,19 @@ def main():
     changed = False
 
     query_all_results = []
+    execution_time_ms = []
     rowcount = 0
     statusmessage = ''
 
     # Execute query:
     for query in query_list:
         try:
-            cursor.execute(query, args)
+            current_query_txt = cursor.mogrify(query, args)
+
+            cursor, exec_time_ms = execute_and_return_time(cursor, query, args)
+
+            execution_time_ms.append(exec_time_ms)
+
             statusmessage = cursor.statusmessage
             if cursor.rowcount > 0:
                 rowcount += cursor.rowcount
@@ -456,24 +420,26 @@ def main():
                     # An explicit conversion is required on the module's side
                     row = dict(row)
                     for (key, val) in iteritems(row):
-                        if isinstance(val, decimal.Decimal):
-                            row[key] = float(val)
-
-                        elif isinstance(val, datetime.timedelta):
-                            row[key] = str(val)
+                        if isinstance(val, TYPES_NEED_TO_CONVERT):
+                            row[key] = convert_to_supported(val)
 
                     query_result.append(row)
 
-            except Psycopg2ProgrammingError as e:
+            # Psycopg 3 doesn't fail with 'no results to fetch'
+            # This exception will be triggered only in Psycopg 2
+            except PsycopgProgrammingError as e:
                 if to_native(e) == 'no results to fetch':
                     query_result = {}
 
             except Exception as e:
                 module.fail_json(msg="Cannot fetch rows from cursor: %s" % to_native(e))
 
+            if query_result == []:
+                query_result = {}
+
             query_all_results.append(query_result)
 
-            if 'SELECT' not in statusmessage:
+            if 'SELECT' not in statusmessage and 'SHOW' not in statusmessage:
                 if re.search(re.compile(r'(UPDATE|INSERT|DELETE)'), statusmessage):
                     s = statusmessage.split()
                     if len(s) == 3:
@@ -506,12 +472,13 @@ def main():
 
     kw = dict(
         changed=changed,
-        query=cursor.query,
+        query=current_query_txt,
         query_list=query_list,
         statusmessage=statusmessage,
         query_result=query_result,
         query_all_results=query_all_results,
         rowcount=rowcount,
+        execution_time_ms=execution_time_ms,
     )
 
     cursor.close()
