@@ -6,15 +6,12 @@
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
-import json
-import pytest
+from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import patch, MagicMock
+from ansible_collections.community.internal_test_tools.tests.unit.plugins.modules.utils import set_module_args, AnsibleExitJson, AnsibleFailJson, ModuleTestCase
 
-from ansible_collections.community.routeros.tests.unit.compat.mock import patch, MagicMock
 from ansible_collections.community.routeros.tests.unit.plugins.modules.fake_api import (
     FakeLibRouterosError, fake_ros_api, massage_expected_result_data, create_fake_path,
 )
-from ansible_collections.community.routeros.tests.unit.plugins.modules.utils import set_module_args, AnsibleExitJson, AnsibleFailJson, ModuleTestCase
-from ansible_collections.community.routeros.plugins.module_utils._api_data import PATHS
 from ansible_collections.community.routeros.plugins.modules import api_find_and_modify
 
 
@@ -121,8 +118,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
 
     def test_module_fail_when_required_args_missing(self):
         with self.assertRaises(AnsibleFailJson) as exc:
-            set_module_args({})
-            self.module.main()
+            with set_module_args({}):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -140,8 +137,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                     'comment': 'bar',
                 },
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -159,8 +156,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                     'comment': 'bar',
                 },
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -177,8 +174,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                     '!comment': None,
                 },
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -194,8 +191,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                     '!comment': 'gone',
                 },
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -216,8 +213,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 },
                 'require_matches_min': 10,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -238,8 +235,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 },
                 'require_matches_min': 10,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -260,8 +257,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 },
                 'require_matches_max': 1,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -281,8 +278,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                     'name': 'bam',
                 },
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -307,8 +304,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'require_matches_min': 2,
                 'allow_no_matches': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -329,8 +326,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'values': {
                 },
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -353,8 +350,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                     'comment': None,
                 },
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -378,8 +375,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 },
                 '_ansible_diff': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -393,6 +390,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -401,6 +399,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -410,6 +409,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
         ])
         self.assertEqual(result['diff']['before']['values'], [
@@ -420,6 +420,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
         ])
         self.assertEqual(result['diff']['after']['values'], [
@@ -431,6 +432,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
         ])
         self.assertEqual(result['match_count'], 1)
@@ -449,8 +451,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                     'comment': None,
                 },
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -463,6 +465,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -471,6 +474,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -479,6 +483,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
         ])
         self.assertEqual('diff' in result, False)
@@ -498,8 +503,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                     'comment': '',
                 },
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -512,6 +517,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -520,6 +526,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -528,6 +535,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
         ])
         self.assertEqual(result['match_count'], 3)
@@ -546,8 +554,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                     '!comment': None,
                 },
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -560,6 +568,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*A',
@@ -568,6 +577,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
             {
                 '.id': '*7',
@@ -576,6 +586,7 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'ttl': '1d',
                 'disabled': False,
                 'dynamic': False,
+                'match-subdomain': False,
             },
         ])
         self.assertEqual(result['match_count'], 3)
@@ -596,8 +607,8 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                     '!connection-state': None,
                 },
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -609,25 +620,37 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'chain': 'input',
                 'comment': 'defconf',
                 'protocol': 'icmp',
+                'disabled': False,
+                'log': False,
+                'log-prefix': '',
             },
             {
                 '.id': '*3',
                 'action': 'accept',
                 'chain': 'input',
                 'comment': 'defconf',
+                'disabled': False,
+                'log': False,
+                'log-prefix': '',
             },
             {
                 '.id': '*4',
                 'action': 'accept',
                 'chain': 'input',
                 'comment': 'defconf',
+                'disabled': False,
+                'log': False,
+                'log-prefix': '',
             },
             {
                 '.id': '*7',
                 'action': 'drop',
                 'chain': 'input',
                 'comment': 'defconf',
+                'disabled': False,
                 'in-interface': 'wan',
+                'log': False,
+                'log-prefix': '',
             },
             {
                 '.id': '*8',
@@ -635,6 +658,9 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'chain': 'forward',
                 'comment': 'defconf',
                 'connection-state': 'established',
+                'disabled': False,
+                'log': False,
+                'log-prefix': '',
             },
             {
                 '.id': '*9',
@@ -642,6 +668,9 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'chain': 'forward',
                 'comment': 'defconf',
                 'connection-state': 'related',
+                'disabled': False,
+                'log': False,
+                'log-prefix': '',
             },
             {
                 '.id': '*A',
@@ -649,6 +678,9 @@ class TestRouterosApiFindAndModifyModule(ModuleTestCase):
                 'chain': 'forward',
                 'comment': 'defconf',
                 'connection-status': 'invalid',
+                'disabled': False,
+                'log': False,
+                'log-prefix': '',
             },
         ])
         self.assertEqual(result['match_count'], 3)
