@@ -6,11 +6,12 @@
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
-from ansible_collections.community.routeros.tests.unit.compat.mock import patch, MagicMock
+from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import patch, MagicMock
+from ansible_collections.community.internal_test_tools.tests.unit.plugins.modules.utils import set_module_args, AnsibleExitJson, AnsibleFailJson, ModuleTestCase
+
 from ansible_collections.community.routeros.tests.unit.plugins.modules.fake_api import (
     FAKE_ROS_VERSION, FakeLibRouterosError, Key, fake_ros_api,
 )
-from ansible_collections.community.routeros.tests.unit.plugins.modules.utils import set_module_args, AnsibleExitJson, AnsibleFailJson, ModuleTestCase
 from ansible_collections.community.routeros.plugins.modules import api_info
 
 
@@ -41,8 +42,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
 
     def test_module_fail_when_required_args_missing(self):
         with self.assertRaises(AnsibleFailJson) as exc:
-            set_module_args({})
-            self.module.main()
+            with set_module_args({}):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -53,8 +54,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
             args.update({
                 'path': 'something invalid'
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -68,8 +69,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
             args.update({
                 'path': 'ip dns static'
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -93,8 +94,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
             args.update({
                 'path': 'caps-man aaa',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -122,8 +123,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                 'path': 'caps-man aaa',
                 'hide_defaults': False,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -155,8 +156,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                 'path': 'caps-man aaa',
                 'unfiltered': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -189,8 +190,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                 'path': 'ip firewall filter',
                 'handle_disabled': 'exclamation',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -278,8 +279,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                 'path': 'ip firewall filter',
                 'handle_disabled': 'null-value',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -367,8 +368,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                 'path': 'ip firewall filter',
                 'handle_disabled': 'omit',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -402,8 +403,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                 'handle_disabled': 'omit',
                 'include_dynamic': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -460,8 +461,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                 'path': 'interface list',
                 'handle_disabled': 'omit',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -513,8 +514,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                 'handle_disabled': 'omit',
                 'include_builtin': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -605,8 +606,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                 'path': 'ip dhcp-server lease',
                 'handle_disabled': 'omit',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -688,8 +689,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
             args.update({
                 'path': 'interface gre',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -776,8 +777,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                 'handle_disabled': 'omit',
                 'hide_defaults': False,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -847,8 +848,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                 'handle_disabled': 'omit',
                 'restrict': [],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -899,8 +900,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                     'values': ['forward'],
                 }],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -970,8 +971,8 @@ class TestRouterosApiInfoModule(ModuleTestCase):
                     },
                 ],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
