@@ -1,8 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright: (c) 2019, Ansible Project
 # Copyright: (c) 2019, VMware, Inc. All Rights Reserved.
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -14,29 +16,23 @@ module: vmware_guest_controller
 short_description: Manage disk or USB controllers related to virtual machine in given vCenter infrastructure
 description:
     - This module can be used to add, remove disk controllers or USB controllers belonging to given virtual machine.
-    - All parameters and VMware object names are case sensitive.
 author:
     - Diane Wang (@Tomorrow9) <dianew@vmware.com>
-notes:
-    - Tested on vSphere 6.0, 6.5 and 6.7
-requirements:
-    - "python >= 2.7"
-    - PyVmomi
 options:
    name:
      description:
      - Name of the virtual machine.
-     - This is a required parameter, if parameter C(uuid) or C(moid) is not supplied.
+     - This is a required parameter, if parameter O(uuid) or O(moid) is not supplied.
      type: str
    uuid:
      description:
      - UUID of the instance to gather facts if known, this is VMware's unique identifier.
-     - This is a required parameter, if parameter C(name) or C(moid) is not supplied.
+     - This is a required parameter, if parameter O(name) or O(moid) is not supplied.
      type: str
    moid:
      description:
      - Managed Object ID of the instance to manage if known, this is a unique identifier only within a single vCenter instance.
-     - This is required if C(name) or C(uuid) is not supplied.
+     - This is required if O(name) or O(uuid) is not supplied.
      type: str
    folder:
      description:
@@ -73,8 +69,8 @@ options:
      suboptions:
        controller_number:
          description:
-         - Disk controller bus number. When C(state) is set to C(absent), this parameter is required.
-         - When C(type) set to C(usb2) or C(usb3), this parameter is not required.
+         - Disk controller bus number. When O(controllers[].state=absent), this parameter is required.
+         - When O(controllers[].type=usb2) or O(controllers[].type=usb3), this parameter is not required.
          type: int
          choices:
            - 0
@@ -84,7 +80,7 @@ options:
        type:
          description:
          - Type of disk or USB controller.
-         - From vSphere 6.5 and virtual machine with hardware version 13, C(nvme) controller starts to be supported.
+         - From vSphere 6.5 and virtual machine with hardware version 13, V(nvme) controller starts to be supported.
          required: true
          type: str
          choices:
@@ -99,9 +95,9 @@ options:
        state:
          description:
          - Add new controller or remove specified existing controller.
-         - If C(state) is set to C(absent), the specified controller will be removed from virtual machine when there is no disk or device attaching to it.
+         - If set to V(absent), the specified controller will be removed from virtual machine when there is no disk or device attaching to it.
          - If specified controller is removed or not exist, no action will be taken only warning message.
-         - If C(state) is set to C(present), new controller with specified type will be added.
+         - If set to V(present), new controller with specified type will be added.
          - If the number of controller with specified controller type reaches it's maximum, no action will be taken only warning message.
          required: true
          type: str
@@ -111,19 +107,18 @@ options:
        bus_sharing:
          description:
          - Bus sharing type for SCSI controller.
-         required: False
+         required: false
          type: str
          choices: ['noSharing', 'physicalSharing', 'virtualSharing' ]
          default: 'noSharing'
-         version_added: 1.11.0
      type: list
      elements: dict
    gather_disk_controller_facts:
      description:
      - Whether to collect existing disk and USB controllers facts only.
-     - When this parameter is set to C(True), C(controllers) parameter will be ignored.
+     - When this parameter is set to V(true), O(controllers) parameter will be ignored.
      type: bool
-     default: False
+     default: false
    sleep_time:
      description:
      - 'The sleep time in seconds after VM reconfigure task completes, used when not get the updated VM controller
@@ -251,7 +246,8 @@ except ImportError:
 import time
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils._text import to_native
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec, wait_for_task, TaskError
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, wait_for_task, TaskError
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 from ansible_collections.community.vmware.plugins.module_utils.vm_device_helper import PyVmomiDeviceHelper
 
 
@@ -494,7 +490,7 @@ class PyVmomiHelper(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         name=dict(type='str'),
         uuid=dict(type='str'),
