@@ -1,8 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright: (c) 2018, Ansible Project
 # Copyright: (c) 2018, Abhijeet Kasurde <akasurde@redhat.com>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -14,31 +16,25 @@ module: vmware_guest_disk
 short_description: Manage disks related to virtual machine in given vCenter infrastructure
 description:
     - This module can be used to add, remove and update disks belonging to given virtual machine.
-    - All parameters and VMware object names are case sensitive.
     - This module is destructive in nature, please read documentation carefully before proceeding.
     - Be careful while removing disk specified as this may lead to data loss.
 author:
     - Abhijeet Kasurde (@Akasurde) <akasurde@redhat.com>
-notes:
-    - Tested on vSphere 6.0 and 6.5
-requirements:
-    - "python >= 2.6"
-    - PyVmomi
 options:
    name:
      description:
      - Name of the virtual machine.
-     - This is a required parameter, if parameter C(uuid) or C(moid) is not supplied.
+     - This is a required parameter, if parameter O(uuid) or O(moid) is not supplied.
      type: str
    uuid:
      description:
      - UUID of the instance to gather facts if known, this is VMware's unique identifier.
-     - This is a required parameter, if parameter C(name) or C(moid) is not supplied.
+     - This is a required parameter, if parameter O(name) or O(moid) is not supplied.
      type: str
    moid:
      description:
      - Managed Object ID of the instance to manage if known, this is a unique identifier only within a single vCenter instance.
-     - This is required if C(name) or C(uuid) is not supplied.
+     - This is required if O(name) or O(uuid) is not supplied.
      type: str
    folder:
      description:
@@ -59,7 +55,7 @@ options:
    datacenter:
      description:
      - The datacenter name to which virtual machine belongs to.
-     required: True
+     required: true
      type: str
    use_instance_uuid:
      description:
@@ -70,7 +66,6 @@ options:
      description:
      - A list of disks to add or remove.
      - The virtual disk related information is provided using this list.
-     - All values and parameters are case sensitive.
      suboptions:
        size:
          description:
@@ -92,53 +87,55 @@ options:
          type: int
        type:
          description:
-         - The type of disk, if not specified then use C(thick) type for new disk, no eagerzero.
-         - The disk type C(rdm) is added in version 1.13.0.
+         - The type of disk, if not specified then use V(thick) type for new disk, no eagerzero.
          type: str
-         choices: ['thin', 'eagerzeroedthick', 'thick', 'rdm' ]
+         choices: ['thin', 'eagerzeroedthick', 'thick', 'rdm', 'vpmemdisk']
        disk_mode:
          description:
-           - Type of disk mode. If not specified then use C(persistent) mode for new disk.
-           - If set to 'persistent' mode, changes are immediately and permanently written to the virtual disk.
-           - If set to 'independent_persistent' mode, same as persistent, but not affected by snapshots.
-           - If set to 'independent_nonpersistent' mode, changes to virtual disk are made to a redo log and discarded
+           - Type of disk mode. If not specified then use V(persistent) mode for new disk.
+           - If set to V(persistent) mode, changes are immediately and permanently written to the virtual disk.
+           - If set to V(independent_persistent) mode, same as persistent, but not affected by snapshots.
+           - If set to V('independent_nonpersistent) mode, changes to virtual disk are made to a redo log and discarded
              at power off, but not affected by snapshots.
+           - Not applicable when disk O(disk[].type=vpmemdisk).
          type: str
          choices: ['persistent', 'independent_persistent', 'independent_nonpersistent']
        rdm_path:
          description:
-         - Path of LUN for Raw Device Mapping required for disk type C(rdm).
-         - Only valid if C(type) is set to C(rdm).
+         - Path of LUN for Raw Device Mapping required for O(disk[].type=rdm).
+         - Only valid if O(disk[].type=rdm).
          type: str
        cluster_disk:
          description:
            - This value allows for the sharing of an RDM between two machines.
-           - The primary machine holding the RDM uses the default C(False).
-           - The secondary machine holding the RDM uses C(True).
+           - The primary machine holding the RDM uses the default V(false).
+           - The secondary machine holding the RDM uses V(true).
          type: bool
-         default: False
-         version_added: '1.17.0'
+         default: false
        compatibility_mode:
-         description: Compatibility mode for raw devices. Required for disk type 'rdm'
+         description: Compatibility mode for raw devices. Required when O(disk[].type=rdm).
          type: str
          choices: ['physicalMode','virtualMode']
        sharing:
          description:
            - The sharing mode of the virtual disk.
            - Setting sharing means that multiple virtual machines can write to the virtual disk.
-           - Sharing can only be set if C(type) is set to C(eagerzeroedthick)or C(rdm).
+           - Sharing can only be set if O(disk[].type=eagerzeroedthick) or O(disk[].type=rdm).
          type: bool
-         default: False
+         default: false
        datastore:
-         description: Name of datastore or datastore cluster to be used for the disk.
+         description:
+           - Name of datastore or datastore cluster to be used for the disk.
+           - Not applicable when disk O(disk[].type=vpmemdisk).
          type: str
        autoselect_datastore:
-         description: Select the less used datastore. Specify only if C(datastore) is not specified.
+         description:
+           - Select the less used datastore. Specify only if O(disk[].datastore) is not specified.
+           - Not applicable when disk O(disk[].type=vpmemdisk).
          type: bool
        scsi_controller:
          description:
            - SCSI controller number. Only 4 SCSI controllers are allowed per VM.
-           - Care should be taken while specifying 'scsi_controller' is 0 and 'unit_number' as 0 as this disk may contain OS.
          type: int
          choices: [0, 1, 2, 3]
        bus_sharing:
@@ -148,36 +145,37 @@ options:
          type: str
          choices: ['noSharing', 'physicalSharing', 'virtualSharing']
          default: 'noSharing'
-         version_added: '1.17.0'
        unit_number:
          description:
            - Disk Unit Number.
            - Valid value range from 0 to 15, except 7 for SCSI Controller.
-           - Valid value range from 0 to 64, except 7 for Paravirtual SCSI Controller on Virtual Hardware version 14 or higher
+           - Valid value range from 0 to 64, except 7 for Paravirtual SCSI Controller on Virtual Hardware version 14 or higher.
            - Valid value range from 0 to 29 for SATA controller.
            - Valid value range from 0 to 14 for NVME controller.
+           - Valid value range from 0 to 1 for IDE controller.
          type: int
-         required: True
+         required: true
        scsi_type:
          description:
            - Type of SCSI controller. This value is required only for the first occurrence of SCSI Controller.
-           - This value is ignored, if SCSI Controller is already present or C(state) is C(absent).
+           - This value is ignored, if SCSI Controller is already present or O(disk[].state=absent).
          type: str
          choices: ['buslogic', 'lsilogic', 'lsilogicsas', 'paravirtual']
        destroy:
-         description: If C(state) is C(absent), make sure the disk file is deleted from the datastore. Added in version 2.10.
+         description: If O(disk[].state=absent), make sure the disk file is deleted from the datastore.
          type: bool
-         default: True
+         default: true
        filename:
          description:
            - Existing disk image to be used. Filename must already exist on the datastore.
-           - Specify filename string in C([datastore_name] path/to/file.vmdk) format. Added in version 2.10.
+           - Specify filename string in C([datastore_name] path/to/file.vmdk) format.
+           - Not applicable when disk O(disk[].type=vpmemdisk).
          type: str
        state:
          description:
            - State of disk.
-           - If set to 'absent', disk will be removed permanently from virtual machine configuration and from VMware storage.
-           - If set to 'present', disk will be added if not present at given Controller and Unit Number.
+           - If set to V(absent), disk will be removed permanently from virtual machine configuration and from VMware storage.
+           - If set to V(present), disk will be added if not present at given Controller and Unit Number.
            - or disk exists with different size, disk size is increased, reducing disk size is not allowed.
          type: str
          choices: ['present', 'absent']
@@ -185,15 +183,19 @@ options:
        controller_type:
          description:
            - This parameter is added for managing disks attaching other types of controllers, e.g., SATA or NVMe.
-           - If either C(controller_type) or C(scsi_type) is not specified, then use C(paravirtual) type.
+           - If either O(disk[].controller_type) or O(disk[].scsi_type) is not specified, then use V(paravirtual) type.
          type: str
-         choices: ['buslogic', 'lsilogic', 'lsilogicsas', 'paravirtual', 'sata', 'nvme']
+         choices: ['buslogic', 'lsilogic', 'lsilogicsas', 'paravirtual', 'sata', 'nvme', 'ide']
        controller_number:
-         description: This parameter is used with C(controller_type) for specifying controller bus number.
+         description:
+           - This parameter is used with O(disk[].controller_type) for specifying controller bus number.
+           - For O(disk[].controller_type=ide), valid value is 0 or 1.
          type: int
          choices: [0, 1, 2, 3]
        iolimit:
-         description: Section specifies the shares and limit for storage I/O resource.
+         description:
+           - Section specifies the shares and limit for storage I/O resource.
+           - Not applicable when O(disk[].type=vpmemdisk).
          suboptions:
            limit:
              description: Section specifies values for limit where the utilization of a virtual machine will not exceed, even if there are available resources.
@@ -206,19 +208,21 @@ options:
                  type: str
                  choices: ['low', 'normal', 'high', 'custom']
                level_value:
-                 description: Custom value when C(level) is set as C(custom).
+                 description: Custom value when O(disk[].iolimit.shares.level=custom).
                  type: int
              type: dict
          type: dict
        shares:
-         description: Section for iolimit section tells about what are all different types of shares user can add for disk.
+         description:
+           - Section for iolimit section tells about what are all different types of shares user can add for disk.
+           - Not applicable when disk O(disk[].type=vpmemdisk).
          suboptions:
            level:
              description: Tells about different level for the shares section.
              type: str
              choices: ['low', 'normal', 'high', 'custom']
            level_value:
-             description: Custom value when C(level) is set as C(custom).
+             description: Custom value when O(disk[].shares.level=custom).
              type: int
          type: dict
      default: []
@@ -248,7 +252,7 @@ EXAMPLES = r'''
       - size_gb: 10
         type: eagerzeroedthick
         state: present
-        autoselect_datastore: True
+        autoselect_datastore: true
         scsi_controller: 2
         scsi_type: 'buslogic'
         unit_number: 12
@@ -256,7 +260,7 @@ EXAMPLES = r'''
       - size: 10Gb
         type: eagerzeroedthick
         state: present
-        autoselect_datastore: True
+        autoselect_datastore: true
         scsi_controller: 2
         scsi_type: 'buslogic'
         unit_number: 1
@@ -291,7 +295,7 @@ EXAMPLES = r'''
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
     datacenter: "{{ datacenter_name }}"
-    validate_certs: no
+    validate_certs: false
     name: "Test_VM"
     disk:
       - type: rdm
@@ -307,7 +311,7 @@ EXAMPLES = r'''
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
     datacenter: "{{ datacenter_name }}"
-    validate_certs: no
+    validate_certs: false
     name: "Test_VM"
     disk:
       - type: rdm
@@ -324,7 +328,7 @@ EXAMPLES = r'''
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
     datacenter: "{{ datacenter_name }}"
-    validate_certs: no
+    validate_certs: false
     name: "Test_VM"
     disk:
       - type: rdm
@@ -342,7 +346,7 @@ EXAMPLES = r'''
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
     datacenter: "{{ datacenter_name }}"
-    validate_certs: no
+    validate_certs: false
     name: "Test_VM"
     disk:
       - type: rdm
@@ -415,7 +419,7 @@ EXAMPLES = r'''
       - state: absent
         scsi_controller: 1
         unit_number: 2
-        destroy: no
+        destroy: false
   delegate_to: localhost
   register: disk_facts
 
@@ -425,7 +429,7 @@ EXAMPLES = r'''
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
     datacenter: "{{ datacenter_name }}"
-    validate_certs: no
+    validate_certs: false
     uuid: 421e4592-c069-924d-ce20-7e7533fab926
     disk:
       - size_mb: 256
@@ -438,17 +442,35 @@ EXAMPLES = r'''
         disk_mode: 'persistent'
       - size_gb: 1
         state: present
-        autoselect_datastore: True
+        autoselect_datastore: true
         controller_type: nvme
         controller_number: 2
         unit_number: 3
         disk_mode: 'independent_persistent'
   delegate_to: localhost
   register: disk_facts
+
+- name: Add a new vPMem disk to virtual machine to SATA controller
+  community.vmware.vmware_guest_disk:
+    hostname: "{{ vcenter_hostname }}"
+    username: "{{ vcenter_username }}"
+    password: "{{ vcenter_password }}"
+    datacenter: "{{ datacenter_name }}"
+    validate_certs: false
+    name: VM_226
+    disk:
+      - type: vpmemdisk
+        size_gb: 1
+        state: present
+        controller_type: sata
+        controller_number: 1
+        unit_number: 2
+  delegate_to: localhost
+  register: disk_facts
 '''
 
 RETURN = r'''
-disk_status:
+disk_data:
     description: metadata about the virtual machine's disks after managing them
     returned: always
     type: dict
@@ -470,6 +492,14 @@ disk_status:
             "unit_number": 0
         },
     }
+disk_changes:
+    description: result of each task, key is the 0-based index with the same sequence in which the tasks were defined
+    returned: always
+    type: dict
+    sample: {
+        "0": "Disk deleted.",
+        "1": "Disk created."
+    }
 '''
 
 import re
@@ -481,8 +511,9 @@ except ImportError:
 from random import randint
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils._text import to_native
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec,\
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, \
     wait_for_task, find_obj, get_all_objs, get_parent_datacenter
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 from ansible_collections.community.vmware.plugins.module_utils.vm_device_helper import PyVmomiDeviceHelper
 
 
@@ -492,8 +523,6 @@ class PyVmomiHelper(PyVmomi):
         self.device_helper = PyVmomiDeviceHelper(self.module)
         self.desired_disks = self.params['disk']  # Match with vmware_guest parameter
         self.vm = None
-        self.ctl_device_type = self.device_helper.scsi_device_type.copy()
-        self.ctl_device_type.update({'sata': self.device_helper.sata_device_type, 'nvme': self.device_helper.nvme_device_type})
         self.config_spec = vim.vm.ConfigSpec()
         self.config_spec.deviceChange = []
 
@@ -528,19 +557,23 @@ class PyVmomiHelper(PyVmomi):
             disk_spec.device.backing = vim.vm.device.VirtualDisk.RawDiskMappingVer1BackingInfo()
             disk_spec.device.backing.deviceName = disk['rdm_path']
             disk_spec.device.backing.compatibilityMode = disk['compatibility_mode']
+        elif disk['disk_type'] == 'vpmemdisk':
+            disk_spec.device.backing = vim.vm.device.VirtualDisk.LocalPMemBackingInfo()
         else:
             disk_spec.device.backing = vim.vm.device.VirtualDisk.FlatVer2BackingInfo()
 
-        disk_spec.device.backing.diskMode = disk['disk_mode']
-        disk_spec.device.backing.sharing = disk['sharing']
+        if disk['disk_type'] != 'vpmemdisk':
+            disk_spec.device.backing.diskMode = disk['disk_mode']
+            disk_spec.device.backing.sharing = disk['sharing']
+
+            if disk['disk_type'] == 'thin':
+                disk_spec.device.backing.thinProvisioned = True
+            elif disk['disk_type'] == 'eagerzeroedthick':
+                disk_spec.device.backing.eagerlyScrub = True
+
         disk_spec.device.controllerKey = ctl_key
         disk_spec.device.unitNumber = disk['disk_unit_number']
 
-        if disk['disk_type'] == 'thin':
-            disk_spec.device.backing.thinProvisioned = True
-        elif disk['disk_type'] == 'eagerzeroedthick':
-            disk_spec.device.backing.eagerlyScrub = True
-
         return disk_spec
 
     def reconfigure_vm(self, config_spec, device_type):
@@ -626,6 +659,7 @@ class PyVmomiHelper(PyVmomi):
         disk_change_list = list()
         results = dict(changed=False, disk_data=None, disk_changes=dict())
         new_added_disk_ctl = list()
+        sharesval = {'low': 500, 'normal': 1000, 'high': 2000}
 
         # Deal with controller
         for disk in disk_data:
@@ -638,7 +672,7 @@ class PyVmomiHelper(PyVmomi):
             # check if disk controller already exists
             if not ctl_found:
                 for device in self.vm.config.hardware.device:
-                    if isinstance(device, self.ctl_device_type[disk['controller_type']]):
+                    if isinstance(device, self.device_helper.disk_ctl_device_type[disk['controller_type']]):
                         if device.busNumber == disk['controller_number']:
                             ctl_found = True
                             break
@@ -666,18 +700,38 @@ class PyVmomiHelper(PyVmomi):
         # Deal with Disks
         for disk in disk_data:
             disk_found = False
+            update_io = False
             disk_change = False
             ctl_found = False
             for device in self.vm.config.hardware.device:
-                if isinstance(device, self.ctl_device_type[disk['controller_type']]) and device.busNumber == disk['controller_number']:
+                if isinstance(device, self.device_helper.disk_ctl_device_type[disk['controller_type']]) and device.busNumber == disk['controller_number']:
                     for disk_key in device.device:
                         disk_device = self.find_disk_by_key(disk_key, disk['disk_unit_number'])
                         if disk_device is not None:
                             disk_found = True
                             if disk['state'] == 'present':
                                 disk_spec = vim.vm.device.VirtualDeviceSpec()
-                                # set the operation to edit so that it knows to keep other settings
                                 disk_spec.device = disk_device
+                                # Deal with iolimit. Note that if iolimit is set, you HAVE TO both set limit and shares,
+                                #  or ansible will break with "'NoneType' object is not subscriptable"
+                                if 'iolimit' in disk:
+                                    if disk['iolimit']['limit'] != disk_spec.device.storageIOAllocation.limit:
+                                        update_io = True
+
+                                    if 'shares' in disk['iolimit']:
+                                        # 'low', 'normal' and 'high' values in disk['iolimit']['shares']['level'] are converted to int values on vcenter side
+                                        if (disk['iolimit']['shares']['level'] != 'custom'
+                                            and sharesval.get(disk['iolimit']['shares']['level'], 0) != disk_spec.device.storageIOAllocation.shares.shares) or \
+                                            (disk['iolimit']['shares']['level'] == 'custom'
+                                                and disk['iolimit']['shares']['level_value'] != disk_spec.device.storageIOAllocation.shares.shares):
+                                            update_io = True
+
+                                    if update_io:
+                                        # set the operation to edit so that it knows to keep other settings
+                                        disk_spec.operation = vim.vm.device.VirtualDeviceSpec.Operation.edit
+                                        disk_spec = self.get_ioandshares_diskconfig(disk_spec, disk)
+                                        disk_change = True
+
                                 # If this is an RDM ignore disk size
                                 if disk['disk_type'] != 'rdm':
                                     if disk['size'] < disk_spec.device.capacityInKB:
@@ -686,13 +740,17 @@ class PyVmomiHelper(PyVmomi):
                                                                   % (disk['disk_index'], disk['size'],
                                                                       disk_spec.device.capacityInKB))
                                     if disk['size'] != disk_spec.device.capacityInKB:
+                                        # set the operation to edit so that it knows to keep other settings
                                         disk_spec.operation = vim.vm.device.VirtualDeviceSpec.Operation.edit
-                                        disk_spec = self.get_ioandshares_diskconfig(disk_spec, disk)
+                                        if disk['disk_type'] != 'vpmemdisk':
+                                            disk_spec = self.get_ioandshares_diskconfig(disk_spec, disk)
                                         disk_spec.device.capacityInKB = disk['size']
-                                        self.config_spec.deviceChange.append(disk_spec)
                                         disk_change = True
-                                        disk_change_list.append(disk_change)
-                                        results['disk_changes'][disk['disk_index']] = "Disk reconfigured."
+
+                                if disk_change:
+                                    self.config_spec.deviceChange.append(disk_spec)
+                                    disk_change_list.append(disk_change)
+                                    results['disk_changes'][disk['disk_index']] = "Disk reconfigured."
 
                             elif disk['state'] == 'absent':
                                 # Disk already exists, deleting
@@ -748,10 +806,6 @@ class PyVmomiHelper(PyVmomi):
                         disk_change_list.append(disk_change)
                         results['disk_changes'][disk['disk_index']] = "Disk created."
                         break
-                    if not disk_found and disk['state'] == 'absent':
-                        self.module.fail_json(msg="Not found disk with 'controller_type': '%s',"
-                                                  " 'controller_number': '%s', 'unit_number': '%s' to remove."
-                                                  % (disk['controller_type'], disk['controller_number'], disk['disk_unit_number']))
             if disk_change:
                 # Adding multiple disks in a single attempt raises weird errors
                 # So adding single disk at a time.
@@ -760,7 +814,7 @@ class PyVmomiHelper(PyVmomi):
                 self.config_spec.deviceChange = []
         if any(disk_change_list):
             results['changed'] = True
-        results['disk_data'] = self.gather_disk_facts(vm_obj=self.vm)
+        results['disk_data'] = self.device_helper.gather_disk_info(self.vm)
         self.module.exit_json(**results)
 
     def sanitize_disk_inputs(self):
@@ -791,6 +845,18 @@ class PyVmomiHelper(PyVmomi):
                                 sharing=False,
                                 bus_sharing='noSharing',
                                 cluster_disk=False)
+            # Type of Disk
+            if disk['type'] is not None:
+                current_disk['disk_type'] = disk['type']
+            if current_disk['disk_type'] == 'vpmemdisk':
+                if self.vm.runtime.powerState != vim.VirtualMachinePowerState.poweredOff:
+                    self.module.fail_json(msg="Please make sure VM is in powered off state before doing vPMem disk"
+                                              " reconfiguration.")
+                disk['datastore'] = None
+                disk['autoselect_datastore'] = None
+                disk['filename'] = None
+                disk['disk_mode'] = None
+
             # Check state
             if disk['state'] is not None:
                 current_disk['state'] = disk['state']
@@ -805,6 +871,10 @@ class PyVmomiHelper(PyVmomi):
             else:
                 self.module.fail_json(msg="Please specify either 'scsi_type' or 'controller_type' for disk index [%s]."
                                           % disk_index)
+            if current_disk['controller_type'] == 'ide':
+                if self.vm.runtime.powerState != vim.VirtualMachinePowerState.poweredOff:
+                    self.module.fail_json(msg="Please make sure VM is in powered off state before doing IDE disk"
+                                              " reconfiguration.")
 
             # Check controller bus number
             if disk['scsi_controller'] is not None and disk['controller_number'] is None and disk['controller_type'] is None:
@@ -820,6 +890,10 @@ class PyVmomiHelper(PyVmomi):
             except ValueError:
                 self.module.fail_json(msg="Invalid controller bus number '%s' specified"
                                           " for disk index [%s]" % (temp_disk_controller, disk_index))
+            if current_disk['controller_type'] == 'ide' and disk_controller not in [0, 1]:
+                self.module.fail_json(msg="Invalid controller bus number '%s' specified"
+                                          " for disk index [%s], valid value is 0 or 1" % (disk_controller, disk_index))
+
             current_disk['controller_number'] = disk_controller
 
             try:
@@ -856,6 +930,9 @@ class PyVmomiHelper(PyVmomi):
             elif current_disk['controller_type'] == 'nvme' and temp_disk_unit_number not in range(0, 15):
                 self.module.fail_json(msg="Invalid Disk unit number ID specified for NVMe disk [%s] at index [%s],"
                                           " please specify value between 0 to 14" % (temp_disk_unit_number, disk_index))
+            elif current_disk['controller_type'] == 'ide' and temp_disk_unit_number not in [0, 1]:
+                self.module.fail_json(msg="Invalid Disk unit number ID specified for IDE disk [%s] at index [%s],"
+                                          " please specify value 0 or 1" % (temp_disk_unit_number, disk_index))
             current_disk['disk_unit_number'] = temp_disk_unit_number
 
             # By default destroy file from datastore if 'destroy' parameter is not provided
@@ -899,6 +976,10 @@ class PyVmomiHelper(PyVmomi):
                             datastore = ds
                             datastore_freespace = ds.summary.freeSpace
                     current_disk['datastore'] = datastore
+                else:
+                    if current_disk['disk_type'] == 'vpmemdisk':
+                        current_disk['datastore'] = None
+                        current_disk['autoselect_datastore'] = False
 
                 if disk['filename'] is not None:
                     current_disk['filename'] = disk['filename']
@@ -951,7 +1032,7 @@ class PyVmomiHelper(PyVmomi):
                     disk_units = dict(tb=3, gb=2, mb=1, kb=0)
                     unit = unit.lower()
                     if unit in disk_units:
-                        current_disk['size'] = expected * (1024 ** disk_units[unit])
+                        current_disk['size'] = round(expected * (1024 ** disk_units[unit]))
                     else:
                         self.module.fail_json(msg="%s is not a supported unit for disk size for disk index [%s]."
                                                   " Supported units are ['%s']." % (unit, disk_index, "', '".join(disk_units.keys())))
@@ -960,19 +1041,18 @@ class PyVmomiHelper(PyVmomi):
                     self.module.fail_json(msg="No size, size_kb, size_mb, size_gb or size_tb"
                                               " attribute found into disk index [%s] configuration." % disk_index)
 
-                # Type of Disk
-                if disk['type'] is not None:
-                    current_disk['disk_type'] = disk['type']
                 # Mode of Disk
                 if disk['disk_mode'] is not None:
                     current_disk['disk_mode'] = disk['disk_mode']
-                # Sharing mode of disk
-                current_disk['sharing'] = self.get_sharing(disk, current_disk['disk_type'], disk_index)
 
-                if disk['shares'] is not None:
-                    current_disk['shares'] = disk['shares']
-                if disk['iolimit'] is not None:
-                    current_disk['iolimit'] = disk['iolimit']
+                if current_disk['disk_type'] != 'vpmemdisk':
+                    # Sharing mode of disk
+                    current_disk['sharing'] = self.get_sharing(disk, current_disk['disk_type'], disk_index)
+
+                    if disk['shares'] is not None:
+                        current_disk['shares'] = disk['shares']
+                    if disk['iolimit'] is not None:
+                        current_disk['iolimit'] = disk['iolimit']
 
                 # Deal with RDM disk needs. RDMS require some different values compared to Virtual Disks
                 if disk['type'] == 'rdm':
@@ -983,7 +1063,7 @@ class PyVmomiHelper(PyVmomi):
                     current_disk['compatibility_mode'] = compatibility_mode
 
                     # RDMs need a path
-                    if 'rdm_path'not in disk and 'filename' not in disk:
+                    if 'rdm_path' not in disk and 'filename' not in disk:
                         self.module.fail_json(msg="rdm_path and/or 'filename' needs must be specified when using disk type 'rdm'"
                                               "for disk index [%s]" % disk_index)
                     else:
@@ -995,15 +1075,17 @@ class PyVmomiHelper(PyVmomi):
                     else:
                         current_disk['cluster_disk'] = disk.get('cluster_disk')
 
-                # Enable Physical or virtuals SCSI Bus Sharing
+                # Enable Physical or virtual SCSI Bus Sharing
                 if disk['bus_sharing']:
                     bus_sharing = disk.get('bus_sharing', 'noSharing')
                     if bus_sharing not in ['noSharing', 'physicalSharing', 'virtualSharing']:
-                        self.module.fail_json(msg="Invalid SCSI 'bus_sharing' specied for disk index [%s]. Please specify"
-                                              "'bus_sharing' value from['noSharing', 'physicalSharing', 'virtualSharing']." % disk_index)
+                        self.module.fail_json(msg="Invalid SCSI 'bus_sharing' specied for disk index [%s]. Please "
+                                                  "specify 'bus_sharing' value from "
+                                                  "['noSharing', 'physicalSharing', 'virtualSharing']." % disk_index)
                     current_disk['bus_sharing'] = bus_sharing
 
             disks_data.append(current_disk)
+
         return disks_data
 
     def get_recommended_datastore(self, datastore_cluster_obj, disk_spec_obj):
@@ -1054,63 +1136,9 @@ class PyVmomiHelper(PyVmomi):
             return datastore.name
         return None
 
-    @staticmethod
-    def gather_disk_facts(vm_obj):
-        """
-        Gather facts about VM's disks
-        Args:
-            vm_obj: Managed object of virtual machine
-
-        Returns: A list of dict containing disks information
-
-        """
-        disks_facts = dict()
-        if vm_obj is None:
-            return disks_facts
-
-        disk_index = 0
-        for disk in vm_obj.config.hardware.device:
-            if isinstance(disk, vim.vm.device.VirtualDisk):
-                if disk.storageIOAllocation is None:
-                    disk.storageIOAllocation = vim.StorageResourceManager.IOAllocationInfo()
-                    disk.storageIOAllocation.shares = vim.SharesInfo()
-
-                if disk.shares is None:
-                    disk.shares = vim.SharesInfo()
-
-                disks_facts[disk_index] = dict(
-                    key=disk.key,
-                    label=disk.deviceInfo.label,
-                    summary=disk.deviceInfo.summary,
-                    backing_filename=disk.backing.fileName,
-                    backing_datastore=disk.backing.datastore.name,
-                    backing_disk_mode=disk.backing.diskMode,
-                    backing_sharing=disk.backing.sharing,
-                    backing_uuid=disk.backing.uuid,
-                    controller_key=disk.controllerKey,
-                    unit_number=disk.unitNumber,
-                    iolimit_limit=disk.storageIOAllocation.limit,
-                    iolimit_shares_level=disk.storageIOAllocation.shares.level,
-                    iolimit_shares_limit=disk.storageIOAllocation.shares.shares,
-                    shares_level=disk.shares.level,
-                    shares_limit=disk.shares.shares,
-                    capacity_in_kb=disk.capacityInKB,
-                    capacity_in_bytes=disk.capacityInBytes,
-                )
-                if isinstance(disk.backing, vim.vm.device.VirtualDisk.RawDiskMappingVer1BackingInfo):
-                    disks_facts[disk_index].update(backing_devicename=disk.backing.deviceName,
-                                                   backing_compatibility_mode=disk.backing.compatibilityMode)
-
-                else:
-                    disks_facts[disk_index].update(backing_writethrough=disk.backing.writeThrough,
-                                                   backing_thinprovisioned=disk.backing.thinProvisioned,
-                                                   backing_eagerlyscrub=bool(disk.backing.eagerlyScrub))
-                disk_index += 1
-        return disks_facts
-
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         name=dict(type='str'),
         uuid=dict(type='str'),
@@ -1128,7 +1156,7 @@ def main():
                 size_mb=dict(type='int'),
                 size_gb=dict(type='int'),
                 size_tb=dict(type='int'),
-                type=dict(type='str', choices=['thin', 'eagerzeroedthick', 'thick', 'rdm']),
+                type=dict(type='str', choices=['thin', 'eagerzeroedthick', 'thick', 'rdm', 'vpmemdisk']),
                 disk_mode=dict(type='str', choices=['persistent', 'independent_persistent', 'independent_nonpersistent']),
                 compatibility_mode=dict(type='str', choices=['physicalMode', 'virtualMode']),
                 rdm_path=dict(type='str'),
@@ -1141,7 +1169,7 @@ def main():
                 destroy=dict(type='bool', default=True),
                 filename=dict(type='str'),
                 state=dict(type='str', default='present', choices=['present', 'absent']),
-                controller_type=dict(type='str', choices=['buslogic', 'lsilogic', 'paravirtual', 'lsilogicsas', 'sata', 'nvme']),
+                controller_type=dict(type='str', choices=['buslogic', 'lsilogic', 'paravirtual', 'lsilogicsas', 'sata', 'nvme', 'ide']),
                 controller_number=dict(type='int', choices=[0, 1, 2, 3]),
                 bus_sharing=dict(type='str', choices=['noSharing', 'physicalSharing', 'virtualSharing'], default='noSharing'),
                 cluster_disk=dict(type='bool', default=False),
