@@ -11,12 +11,15 @@ __metaclass__ = type
 
 DOCUMENTATION = '''
     name: foreman
-    plugin_type: inventory
     short_description: Foreman inventory source
     requirements:
         - requests >= 1.1
     description:
         - Get inventory hosts from Foreman.
+        - Can use the Reports API (default) or the Hosts API to fetch information about the hosts.
+        - The Reports API is faster with many hosts.
+        - The Reports API requires the C(foreman_ansible) plugin to be installed on the Foreman server.
+        - Some options only work when using the Reports API.
         - Uses a YAML configuration file that ends with ``foreman.(yml|yaml)``.
     extends_documentation_fragment:
         - inventory_cache
@@ -24,12 +27,12 @@ DOCUMENTATION = '''
     options:
       plugin:
         description: token that ensures this is a source file for the C(foreman) plugin.
-        required: True
+        required: true
         choices: ['theforeman.foreman.foreman']
       url:
         description:
           - URL of the Foreman server.
-        default: 'http://localhost:3000'
+        required: true
         env:
             - name: FOREMAN_SERVER
             - name: FOREMAN_SERVER_URL
@@ -37,21 +40,21 @@ DOCUMENTATION = '''
       user:
         description:
           - Username accessing the Foreman server.
-        required: True
+        required: true
         env:
             - name: FOREMAN_USER
             - name: FOREMAN_USERNAME
       password:
         description:
           - Password of the user accessing the Foreman server.
-        required: True
+        required: true
         env:
             - name: FOREMAN_PASSWORD
       validate_certs:
         description:
           - Whether or not to verify the TLS certificates of the Foreman server.
         type: boolean
-        default: False
+        default: true
         env:
             - name: FOREMAN_VALIDATE_CERTS
       group_prefix:
@@ -63,21 +66,21 @@ DOCUMENTATION = '''
       want_facts:
         description: Toggle, if True the plugin will retrieve host facts from the server
         type: boolean
-        default: False
+        default: false
       want_params:
         description: Toggle, if true the inventory will retrieve 'all_parameters' information as host vars
         type: boolean
-        default: False
+        default: false
       want_hostcollections:
         description: Toggle, if true the plugin will create Ansible groups for host collections
         type: boolean
-        default: False
+        default: false
       legacy_hostvars:
         description:
             - Toggle, if true the plugin will build legacy hostvars present in the foreman script
             - Places hostvars in a dictionary with keys `foreman`, `foreman_facts`, and `foreman_params`
         type: boolean
-        default: False
+        default: false
       host_filters:
         description: This can be used to restrict the list of returned host
         type: string
@@ -86,13 +89,13 @@ DOCUMENTATION = '''
         type: int
         default: 250
       use_reports_api:
-        description: Use Reporting API.
+        description: Use Reports API.
         type: boolean
-        default: False
+        default: true
       foreman:
         description:
           - Foreman server related configuration, deprecated.
-          - You can pass I(use_reports_api) in this dict to enable the Reporting API.
+          - You can pass I(use_reports_api) in this dict to enable the Reports API.
           - Only for backward compatibility.
       report:
         description:
@@ -109,46 +112,65 @@ DOCUMENTATION = '''
         type: int
         default: 600
       want_organization:
-        description: Toggle, if true the inventory will fetch organization the host belongs to and create groupings for the same.
+        description:
+          - Toggle, if true the inventory will fetch organization the host belongs to and create groupings for the same.
+          - Only applies to inventories using the Reports API - attribute is ignored otherwise.
         type: boolean
-        default: True
+        default: true
       want_location:
-        description: Toggle, if true the inventory will fetch location the host belongs to and create groupings for the same.
+        description:
+          - Toggle, if true the inventory will fetch location the host belongs to and create groupings for the same.
+          - Only applies to inventories using the Reports API - attribute is ignored otherwise.
         type: boolean
-        default: True
+        default: true
       want_ipv4:
-        description: Toggle, if true the inventory will fetch ipv4 address of the host.
+        description:
+          - Toggle, if true the inventory will fetch ipv4 address of the host.
+          - Only applies to inventories using the Reports API - attribute is ignored otherwise.
         type: boolean
-        default: True
+        default: true
       want_ipv6:
-        description: Toggle, if true the inventory will fetch ipv6 address of the host.
+        description:
+          - Toggle, if true the inventory will fetch ipv6 address of the host.
+          - Only applies to inventories using the Reports API - attribute is ignored otherwise.
         type: boolean
-        default: True
+        default: true
       want_host_group:
-        description: Toggle, if true the inventory will fetch host_groups and create groupings for the same.
+        description:
+          - Toggle, if true the inventory will fetch host_groups and create groupings for the same.
+          - Only applies to inventories using the Reports API - attribute is ignored otherwise.
         type: boolean
-        default: True
+        default: true
       want_subnet:
-        description: Toggle, if true the inventory will fetch subnet.
+        description:
+          - Toggle, if true the inventory will fetch subnet.
+          - Only applies to inventories using the Reports API - attribute is ignored otherwise.
         type: boolean
-        default: True
+        default: true
       want_subnet_v6:
-        description:  Toggle, if true the inventory will fetch ipv6 subnet.
+        description:
+          -  Toggle, if true the inventory will fetch ipv6 subnet.
+          - Only applies to inventories using the Reports API - attribute is ignored otherwise.
         type: boolean
-        default: True
+        default: true
       want_smart_proxies:
-        description: Toggle, if true the inventory will fetch smart proxy that the host is registered to.
+        description:
+          - Toggle, if true the inventory will fetch smart proxy that the host is registered to.
+          - Only applies to inventories using the Reports API - attribute is ignored otherwise.
         type: boolean
-        default: True
+        default: true
       want_content_facet_attributes:
-        description: Toggle, if true the inventory will fetch content view details that the host is tied to.
+        description:
+          - Toggle, if true the inventory will fetch content view details that the host is tied to.
+          - Only applies to inventories using the Reports API - attribute is ignored otherwise.
         type: boolean
-        default: True
+        default: true
       hostnames:
         description:
           - A list of templates in order of precedence to compose inventory_hostname.
           - If the template results in an empty string or None value it is ignored.
         type: list
+        elements: str
         default: ['name']
 '''
 
@@ -168,8 +190,9 @@ password: changeme
 hostnames:
   - name.split('.')[0]
 '''
+import copy
 import json
-from distutils.version import LooseVersion
+from ansible_collections.theforeman.foreman.plugins.module_utils._version import LooseVersion
 from time import sleep
 from ansible.errors import AnsibleError
 from ansible.module_utils._text import to_bytes, to_native, to_text
@@ -181,10 +204,10 @@ try:
     import requests
     if LooseVersion(requests.__version__) < LooseVersion('1.1.0'):
         raise ImportError
+    from requests.auth import HTTPBasicAuth
+    HAS_REQUESTS = True
 except ImportError:
-    raise AnsibleError('This script requires python-requests 1.1 as a minimum version')
-
-from requests.auth import HTTPBasicAuth
+    HAS_REQUESTS = False
 
 
 class InventoryModule(BaseInventoryPlugin, Cacheable, Constructable):
@@ -195,7 +218,7 @@ class InventoryModule(BaseInventoryPlugin, Cacheable, Constructable):
     def __init__(self):
 
         super(InventoryModule, self).__init__()
-        self.MINIMUM_FOREMAN_VERSION_FOR_REPORTING_API = '1.24.0'
+        self.MINIMUM_FOREMAN_VERSION_FOR_REPORTS_API = '1.24.0'
         # from config
         self.foreman_url = None
 
@@ -203,6 +226,9 @@ class InventoryModule(BaseInventoryPlugin, Cacheable, Constructable):
         self.cache_key = None
         self.use_cache = None
 
+        if not HAS_REQUESTS:
+            raise AnsibleError('This script requires python-requests 1.1 as a minimum version')
+
     def verify_file(self, path):
 
         valid = False
@@ -234,7 +260,11 @@ class InventoryModule(BaseInventoryPlugin, Cacheable, Constructable):
             params['page'] = 1
             params['per_page'] = self.get_option('batch_size')
             while True:
-                ret = s.get(url, params=params)
+                # workaround to address the follwing issues where 'verify' is overridden in Requests:
+                #   - https://github.com/psf/requests/issues/3829
+                #   - https://github.com/psf/requests/issues/5209
+                ret = s.get(url, params=params, verify=self.get_option('validate_certs'))
+
                 if ignore_errors and ret.status_code in ignore_errors:
                     break
                 ret.raise_for_status()
@@ -249,8 +279,20 @@ class InventoryModule(BaseInventoryPlugin, Cacheable, Constructable):
                     break
                 elif isinstance(json['results'], MutableMapping):
                     # /facts are returned as dict in 'results'
-                    results = json['results']
-                    break
+                    if not isinstance(results, MutableMapping):
+                        results = {}
+
+                    # check for end of paging
+                    if len(json['results']) == 0:
+                        break
+
+                    for host, facts in json['results'].items():
+                        if host not in results:
+                            results[host] = {}
+                        results[host].update(facts)
+
+                    # get next page
+                    params['page'] += 1
                 else:
                     # /hosts 's 'results' is a list of all hosts, returned is paginated
                     results = results + json['results']
@@ -357,13 +399,20 @@ class InventoryModule(BaseInventoryPlugin, Cacheable, Constructable):
             return False
         status_url = "%s/api/v2/status" % self.foreman_url
         result = self._get_json(status_url)
-        foreman_version = (LooseVersion(result.get('version')) >= LooseVersion(self.MINIMUM_FOREMAN_VERSION_FOR_REPORTING_API))
+        foreman_version = (LooseVersion(result.get('version')) >= LooseVersion(self.MINIMUM_FOREMAN_VERSION_FOR_REPORTS_API))
         return foreman_version
 
     def _post_request(self):
         url = "%s/ansible/api/v2/ansible_inventories/schedule" % self.foreman_url
-        session = self._get_session()
         params = {'input_values': self._fetch_params()}
+
+        if self.use_cache and url in self._cache.get(self.cache_key, {}):
+            return self._cache[self.cache_key][url]
+
+        if self.cache_key not in self._cache:
+            self._cache[self.cache_key] = {}
+
+        session = self._get_session()
         self.poll_interval = self.get_option('poll_interval')
         self.max_timeout = self.get_option('max_timeout')
         # backward compatibility
@@ -376,21 +425,22 @@ class InventoryModule(BaseInventoryPlugin, Cacheable, Constructable):
         ret = session.post(url, json=params)
         if not ret:
             raise Exception("Error scheduling inventory report on foreman. Please check foreman logs!")
-        url = "{0}/{1}".format(self.foreman_url, ret.json().get('data_url'))
+        data_url = "{0}/{1}".format(self.foreman_url, ret.json().get('data_url'))
         polls = 0
-        response = session.get(url)
+        response = session.get(data_url)
         while response:
             if response.status_code != 204 or polls > max_polls:
                 break
             sleep(self.poll_interval)
             polls += 1
-            response = session.get(url)
+            response = session.get(data_url)
         if not response:
             raise Exception("Error receiving inventory report from foreman. Please check foreman logs!")
         elif (response.status_code == 204 and polls > max_polls):
             raise Exception("Timeout receiving inventory report from foreman. Check foreman server and max_timeout in foreman.yml")
         else:
-            return response.json()
+            self._cache[self.cache_key][url] = json.loads(response.json())
+            return self._cache[self.cache_key][url]
 
     def _populate(self):
         if self._use_inventory_report():
@@ -425,7 +475,8 @@ class InventoryModule(BaseInventoryPlugin, Cacheable, Constructable):
         self.groups = dict()
         self.hosts = dict()
         try:
-            inventory_report_response = self._post_request()
+            # We need a deep copy of the data, as we modify it below and this would also modify the cache
+            host_data = copy.deepcopy(self._post_request())
         except Exception as exc:
             self.display.warning("Failed to use Reports API, falling back to Hosts API: {0}".format(exc))
             self._populate_host_api()
@@ -435,9 +486,8 @@ class InventoryModule(BaseInventoryPlugin, Cacheable, Constructable):
         hostnames = self.get_option('hostnames')
         strict = self.get_option('strict')
 
-        host_data = json.loads(inventory_report_response)
         for host in host_data:
-            if not(host):
+            if not host:
                 continue
 
             composed_host_name = self._get_hostname(host, hostnames, strict=strict)
@@ -548,7 +598,7 @@ class InventoryModule(BaseInventoryPlugin, Cacheable, Constructable):
         hostnames = self.get_option('hostnames')
         strict = self.get_option('strict')
         for host in self._get_hosts():
-            if not(host):
+            if not host:
                 continue
 
             composed_host_name = self._get_hostname(host, hostnames, strict=strict)
